@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Emitter;
 
-our $VERSION = '0.010_002'; # TRIAL VERSION
+our $VERSION = '0.010_003'; # TRIAL VERSION
 
 use YAML::PP::Common qw/
     YAML_PLAIN_SCALAR_STYLE YAML_SINGLE_QUOTED_SCALAR_STYLE
@@ -122,7 +122,17 @@ sub mapping_end_event {
 
     my $last = pop @{ $stack };
     if ($last->{index} == 0) {
-        $self->writer->write(" {}\n");
+        my $indent = $last->{indent};
+        my $zero_indent = $last->{zero_indent};
+        if ($last->{zero_indent}) {
+            $indent .= ' ' x $self->indent;
+        }
+        if ($last->{append}) {
+            $self->writer->write(" {}\n");
+        }
+        else {
+            $self->writer->write("$indent\{}\n");
+        }
     }
     $last = $stack->[-1];
     if ($last->{type} eq 'SEQ') {
@@ -156,6 +166,7 @@ sub sequence_start_event {
     $props = join ' ', grep defined, ($anchor, $tag);
 
     my $new_append = 0;
+    my $zero_indent = 0;
     my $append = $last->{append};
     if ($last->{type} eq 'DOC') {
         if ($append and $props) {
@@ -170,6 +181,7 @@ sub sequence_start_event {
     }
     else {
         if ($last->{type} eq 'MAPVALUE') {
+            $zero_indent = 1;
         }
         else {
             if ($append) {
@@ -203,7 +215,13 @@ sub sequence_start_event {
     $self->writer->write($yaml);
     $last->{index}++;
     $last->{append} = 0;
-    my $new_info = { index => 0, indent => $new_indent, info => $info, append => $new_append };
+    my $new_info = {
+        index => 0,
+        indent => $new_indent,
+        info => $info,
+        append => $new_append,
+        zero_indent => $zero_indent,
+    };
     if (($info->{style} || '') eq YAML_FLOW_SEQUENCE_STYLE) {
         $new_info->{type} = 'FLOWSEQ';
     }
@@ -220,7 +238,17 @@ sub sequence_end_event {
 
     my $last = pop @{ $stack };
     if ($last->{index} == 0) {
-        $self->writer->write(" []\n");
+        my $indent = $last->{indent};
+        my $zero_indent = $last->{zero_indent};
+        if ($last->{zero_indent}) {
+            $indent .= ' ' x $self->indent;
+        }
+        if ($last->{append}) {
+            $self->writer->write(" []\n");
+        }
+        else {
+            $self->writer->write("$indent\[]\n");
+        }
     }
     $last = $stack->[-1];
     if ($last->{type} eq 'MAP') {
@@ -242,6 +270,9 @@ sub sequence_end_event {
 my %forbidden_first = (qw/
     ! 1 & 1 * 1 { 1 } 1 [ 1 ] 1 | 1 > 1 @ 1 ` 1 " 1 ' 1
 /, '#' => 1, ',' => 1, " " => 1);
+my %forbidden_first_plus_space = (qw/
+    ? 1 - 1 : 1
+/);
 
 my %control = (
     "\x00" => '\0',
@@ -369,6 +400,14 @@ sub scalar_event {
         }
     }
 
+    if ($style eq YAML_PLAIN_SCALAR_STYLE) {
+        if ($forbidden_first_plus_space{ $first }) {
+            if (length ($value) == 1 or substr($value, 1, 1) =~ m/^\s/) {
+                $style = YAML_SINGLE_QUOTED_SCALAR_STYLE;
+            }
+        }
+    }
+
     if (($style eq YAML_LITERAL_SCALAR_STYLE or $style eq YAML_FOLDED_SCALAR_STYLE) and $value eq '') {
         $style = YAML_DOUBLE_QUOTED_SCALAR_STYLE;
     }
@@ -541,13 +580,20 @@ sub alias_event {
     my $stack = $self->event_stack;
     my $last = $stack->[-1];
     $last->{index}++;
-    $last->{append} = 0;
+    my $append = $last->{append};
     my $indent = $last->{indent};
 
     my $alias = '*' . $info->{value};
 
     if ($last->{type} eq 'MAP') {
-        $self->writer->write("$indent$alias :");
+        my $yaml = '';
+        if ($append) {
+            $yaml .= " ";
+        }
+        else {
+            $yaml .= $indent;
+        }
+        $self->writer->write("$yaml$alias :");
         $last->{type} = 'MAPVALUE';
     }
     elsif ($last->{type} eq 'MAPVALUE') {
@@ -555,15 +601,25 @@ sub alias_event {
         $last->{type} = 'MAP';
     }
     elsif ($last->{type} eq 'SEQ') {
-        $self->writer->write("$indent- $alias\n");
+        my $yaml = '';
+        if (not $append) {
+            $yaml .= $indent;
+        }
+        else {
+            $yaml .= " ";
+        }
+        $yaml .= "- $alias\n";
+        $self->writer->write($yaml);
     }
     elsif ($last->{type} eq 'DOC') {
+        # TODO an alias at document level isn't actually valid
         $self->writer->write("$alias\n");
     }
     else {
         $self->writer->write("$indent: $alias\n");
         $last->{type} = 'MAP';
     }
+    $last->{append} = 0;
 }
 
 sub document_start_event {
