@@ -3,7 +3,7 @@ use warnings;
 package YAML::PP::Schema;
 use B;
 
-our $VERSION = '0.010_002'; # TRIAL VERSION
+our $VERSION = '0.010_003'; # TRIAL VERSION
 
 use YAML::PP::Common qw/ YAML_PLAIN_SCALAR_STYLE /;
 
@@ -120,6 +120,11 @@ sub add_representer {
         };
         return;
     }
+    if (my $class_isa = $args{class_isa}) {
+        my $rep = $representers->{class_isa} ||= [];
+        push @$rep, [ $args{class_isa}, $args{code} ];
+        return;
+    }
     if (my $tied_equals = $args{tied_equals}) {
         my $rep = $representers->{tied_equals} ||= {};
         $rep->{ $tied_equals } = {
@@ -526,7 +531,10 @@ sub register {
             $node->{data} = "$node->{value}";
             return 1;
         },
-    ) for ("", qw/ true TRUE True false FALSE False null NULL Null ~ /);
+    ) for ("", qw/
+        true TRUE True false FALSE False null NULL Null ~
+        .inf .Inf .INF -.inf -.Inf -.INF .nan .NaN .NAN
+    /);
     $schema->add_representer(
         regex => qr{$RE_INT_CORE|$RE_FLOAT_CORE|$RE_INT_OCTAL|$RE_INT_HEX},
         code => sub {
